@@ -1,37 +1,34 @@
 """
-===================
-Namespace Utilities
-===================
+# Namespace Utilities
 
 RDFLib provides mechanisms for managing Namespaces.
 
-In particular, there is a :class:`~rdflib.namespace.Namespace` class
+In particular, there is a [`Namespace`][rdflib.namespace.Namespace] class
 that takes as its argument the base URI of the namespace.
 
-.. code-block:: pycon
+```python
+>>> from rdflib.namespace import Namespace
+>>> RDFS = Namespace("http://www.w3.org/1999/02/22-rdf-syntax-ns#")
 
-    >>> from rdflib.namespace import Namespace
-    >>> RDFS = Namespace("http://www.w3.org/1999/02/22-rdf-syntax-ns#")
+```
 
 Fully qualified URIs in the namespace can be constructed either by attribute
 or by dictionary access on Namespace instances:
 
-.. code-block:: pycon
+```python
+>>> RDFS.seeAlso
+rdflib.term.URIRef('http://www.w3.org/1999/02/22-rdf-syntax-ns#seeAlso')
+>>> RDFS['seeAlso']
+rdflib.term.URIRef('http://www.w3.org/1999/02/22-rdf-syntax-ns#seeAlso')
 
-    >>> RDFS.seeAlso
-    rdflib.term.URIRef('http://www.w3.org/1999/02/22-rdf-syntax-ns#seeAlso')
-    >>> RDFS['seeAlso']
-    rdflib.term.URIRef('http://www.w3.org/1999/02/22-rdf-syntax-ns#seeAlso')
+```
 
-
-Automatic handling of unknown predicates
------------------------------------------
+## Automatic handling of unknown predicates
 
 As a programming convenience, a namespace binding is automatically
-created when :class:`rdflib.term.URIRef` predicates are added to the graph.
+created when [`URIRef`][rdflib.term.URIRef] predicates are added to the graph.
 
-Importable namespaces
------------------------
+## Importable namespaces
 
 The following namespaces are available by directly importing from rdflib:
 
@@ -63,21 +60,37 @@ The following namespaces are available by directly importing from rdflib:
 * WGS
 * XSD
 
-.. code-block:: pycon
+```python
+>>> from rdflib.namespace import RDFS
+>>> RDFS.seeAlso
+rdflib.term.URIRef('http://www.w3.org/2000/01/rdf-schema#seeAlso')
 
-    >>> from rdflib.namespace import RDFS
-    >>> RDFS.seeAlso
-    rdflib.term.URIRef('http://www.w3.org/2000/01/rdf-schema#seeAlso')
+```
 """
 
 from __future__ import annotations
 
 import logging
 import warnings
-from collections.abc import Iterable
+
+try:
+    # Python >= 3.14
+    from annotationlib import (
+        get_annotations,  # type: ignore[attr-defined,unused-ignore]
+    )
+except ImportError:  # pragma: no cover
+    try:
+        # Python >= 3.10
+        from inspect import get_annotations  # type: ignore[attr-defined,unused-ignore]
+    except ImportError:
+
+        def get_annotations(thing: Any) -> dict:
+            return thing.__annotations__
+
+
 from functools import lru_cache
 from pathlib import Path
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING, Any, Dict, Iterable, List, Optional, Set, Tuple, Union
 from unicodedata import category
 from urllib.parse import urldefrag, urljoin
 
@@ -129,9 +142,9 @@ logger = logging.getLogger(__name__)
 
 
 class Namespace(str):
-    """
-    Utility class for quickly generating URIRefs with a common prefix
+    """Utility class for quickly generating URIRefs with a common prefix.
 
+    ```python
     >>> from rdflib.namespace import Namespace
     >>> n = Namespace("http://example.org/")
     >>> n.Person # as attribute
@@ -143,9 +156,11 @@ class Namespace(str):
     >>> n2 = Namespace("http://example2.org/")
     >>> n.Person in n2
     False
+
+    ```
     """
 
-    def __new__(cls, value: str | bytes) -> Namespace:
+    def __new__(cls, value: Union[str, bytes]) -> Namespace:
         try:
             rt = str.__new__(cls, value)
         except UnicodeDecodeError:
@@ -176,6 +191,7 @@ class Namespace(str):
     def __contains__(self, ref: str) -> bool:  # type: ignore[override]
         """Allows to check if a URI is within (starts with) this Namespace.
 
+        ```python
         >>> from rdflib import URIRef
         >>> namespace = Namespace('http://example.org/')
         >>> uri = URIRef('http://example.org/foo')
@@ -187,23 +203,27 @@ class Namespace(str):
         >>> obj = URIRef('http://not.example.org/bar')
         >>> obj in namespace
         False
+
+        ```
         """
         return ref.startswith(self)  # test namespace membership with "ref in ns" syntax
 
 
 class URIPattern(str):
-    """
-    Utility class for creating URIs according to some pattern
-    This supports either new style formatting with .format
-    or old-style with % operator
+    """Utility class for creating URIs according to some pattern.
 
+    This supports either new style formatting with .format
+    or old-style with % operator.
+
+    ```python
     >>> u=URIPattern("http://example.org/%s/%d/resource")
     >>> u%('books', 12345)
     rdflib.term.URIRef('http://example.org/books/12345/resource')
 
+    ```
     """
 
-    def __new__(cls, value: str | bytes) -> URIPattern:
+    def __new__(cls, value: Union[str, bytes]) -> URIPattern:
         try:
             rt = str.__new__(cls, value)
         except UnicodeDecodeError:
@@ -226,7 +246,7 @@ class URIPattern(str):
 # always raise AttributeError if they are not defined and which should not be
 # considered part of __dir__ results. These should be all annotations on
 # `DefinedNamespaceMeta`.
-_DFNS_RESERVED_ATTRS: set[str] = {
+_DFNS_RESERVED_ATTRS: Set[str] = {
     "__slots__",
     "_NS",
     "_warn",
@@ -237,7 +257,7 @@ _DFNS_RESERVED_ATTRS: set[str] = {
 
 # Some libraries probe classes for certain attributes or items.
 # This is a list of those attributes and items that should be ignored.
-_IGNORED_ATTR_LOOKUP: set[str] = {
+_IGNORED_ATTR_LOOKUP: Set[str] = {
     "_pytestfixturefunction",  # pytest tries to look this up on Defined namespaces
     "_partialmethod",  # sphinx tries to look this up during autodoc generation
 }
@@ -246,12 +266,12 @@ _IGNORED_ATTR_LOOKUP: set[str] = {
 class DefinedNamespaceMeta(type):
     """Utility metaclass for generating URIRefs with a common prefix."""
 
-    __slots__: tuple[str, ...] = tuple()
+    __slots__: Tuple[str, ...] = tuple()
 
     _NS: Namespace
     _warn: bool = True
     _fail: bool = False  # True means mimic ClosedNamespace
-    _extras: list[str] = []  # List of non-pythonesque items
+    _extras: List[str] = []  # List of non-pythonesque items
     _underscore_num: bool = False  # True means pass "_n" constructs
 
     @lru_cache(maxsize=None)
@@ -311,7 +331,7 @@ class DefinedNamespaceMeta(type):
         if item_str.startswith(str(this_ns)):
             item_str = item_str[len(str(this_ns)) :]
         return any(
-            item_str in c.__annotations__
+            item_str in get_annotations(c)
             or item_str in c._extras
             or (cls._underscore_num and item_str[0] == "_" and item_str[1:].isdigit())
             for c in cls.mro()
@@ -319,7 +339,7 @@ class DefinedNamespaceMeta(type):
         )
 
     def __dir__(cls) -> Iterable[str]:
-        attrs = {str(x) for x in cls.__annotations__}
+        attrs = {str(x) for x in get_annotations(cls)}
         # Removing these as they should not be considered part of the namespace.
         attrs.difference_update(_DFNS_RESERVED_ATTRS)
         values = {cls[str(x)] for x in attrs}
@@ -328,7 +348,7 @@ class DefinedNamespaceMeta(type):
     def as_jsonld_context(self, pfx: str) -> dict:  # noqa: N804
         """Returns this DefinedNamespace as a JSON-LD 'context' object"""
         terms = {pfx: str(self._NS)}
-        for key, term in self.__annotations__.items():
+        for key, term in get_annotations(self).items():
             if issubclass(term, URIRef):
                 terms[key] = f"{pfx}:{key}"
 
@@ -336,12 +356,12 @@ class DefinedNamespaceMeta(type):
 
 
 class DefinedNamespace(metaclass=DefinedNamespaceMeta):
-    """
-    A Namespace with an enumerated list of members.
-    Warnings are emitted if unknown members are referenced if _warn is True
+    """A Namespace with an enumerated list of members.
+
+    Warnings are emitted if unknown members are referenced if _warn is True.
     """
 
-    __slots__: tuple[str, ...] = tuple()
+    __slots__: Tuple[str, ...] = tuple()
 
     def __init__(self):
         raise TypeError("namespace may not be instantiated")
@@ -354,9 +374,9 @@ class ClosedNamespace(Namespace):
     Trying to create terms not listed is an error
     """
 
-    __uris: dict[str, URIRef]
+    __uris: Dict[str, URIRef]
 
-    def __new__(cls, uri: str, terms: list[str]):
+    def __new__(cls, uri: str, terms: List[str]):
         rt = super().__new__(cls, uri)
         rt.__uris = {t: URIRef(rt + t) for t in terms}  # type: ignore[attr-defined]
         return rt
@@ -386,7 +406,7 @@ class ClosedNamespace(Namespace):
     def __repr__(self) -> str:
         return f"{self.__module__}.{self.__class__.__name__}({str(self)!r})"
 
-    def __dir__(self) -> list[str]:
+    def __dir__(self) -> List[str]:
         return list(self.__uris)
 
     def __contains__(self, ref: str) -> bool:  # type: ignore[override]
@@ -394,7 +414,7 @@ class ClosedNamespace(Namespace):
             ref in self.__uris.values()
         )  # test namespace membership with "ref in ns" syntax
 
-    def _ipython_key_completions_(self) -> list[str]:
+    def _ipython_key_completions_(self) -> List[str]:
         return dir(self)
 
 
@@ -430,39 +450,38 @@ class NamespaceManager:
         * using prefix bindings from prefix.cc which is a online prefixes database
         * not implemented yet - this is aspirational
 
-    .. attention::
+    !!! warning "Breaking changes"
 
-        The namespaces bound for specific values of ``bind_namespaces``
+        The namespaces bound for specific values of `bind_namespaces`
         constitute part of RDFLib's public interface, so changes to them should
         only be additive within the same minor version. Removing values, or
         removing namespaces that are bound by default, constitutes a breaking
         change.
 
-    See the
-    Sample usage
+    See the sample usage
 
-    .. code-block:: pycon
+    ```python
+    >>> import rdflib
+    >>> from rdflib import Graph
+    >>> from rdflib.namespace import Namespace, NamespaceManager
+    >>> EX = Namespace('http://example.com/')
+    >>> namespace_manager = NamespaceManager(Graph())
+    >>> namespace_manager.bind('ex', EX, override=False)
+    >>> g = Graph()
+    >>> g.namespace_manager = namespace_manager
+    >>> all_ns = [n for n in g.namespace_manager.namespaces()]
+    >>> assert ('ex', rdflib.term.URIRef('http://example.com/')) in all_ns
 
-        >>> import rdflib
-        >>> from rdflib import Graph
-        >>> from rdflib.namespace import Namespace, NamespaceManager
-        >>> EX = Namespace('http://example.com/')
-        >>> namespace_manager = NamespaceManager(Graph())
-        >>> namespace_manager.bind('ex', EX, override=False)
-        >>> g = Graph()
-        >>> g.namespace_manager = namespace_manager
-        >>> all_ns = [n for n in g.namespace_manager.namespaces()]
-        >>> assert ('ex', rdflib.term.URIRef('http://example.com/')) in all_ns
-        >>>
+    ```
     """
 
     def __init__(self, graph: Graph, bind_namespaces: _NamespaceSetString = "rdflib"):
         self.graph = graph
-        self.__cache: dict[str, tuple[str, URIRef, str]] = {}
-        self.__cache_strict: dict[str, tuple[str, URIRef, str]] = {}
+        self.__cache: Dict[str, Tuple[str, URIRef, str]] = {}
+        self.__cache_strict: Dict[str, Tuple[str, URIRef, str]] = {}
         self.__log = None
-        self.__strie: dict[str, Any] = {}
-        self.__trie: dict[str, Any] = {}
+        self.__strie: Dict[str, Any] = {}
+        self.__trie: Dict[str, Any] = {}
         # This type declaration is here becuase there is no common base class
         # for all namespaces and without it the inferred type of ns is not
         # compatible with all prefixes.
@@ -525,24 +544,28 @@ class NamespaceManager:
         Result is guaranteed to contain a colon separating the prefix from the
         name, even if the prefix is an empty string.
 
-        .. warning::
-
-            When ``generate`` is `True` (which is the default) and there is no
+        !!! warning "Side-effect"
+            When `generate` is `True` (which is the default) and there is no
             matching namespace for the URI in the namespace manager then a new
-            namespace will be added with prefix ``ns{index}``.
+            namespace will be added with prefix `ns{index}`.
 
-            Thus, when ``generate`` is `True`, this function is not a pure
+            Thus, when `generate` is `True`, this function is not a pure
             function because of this side-effect.
 
             This default behaviour is chosen so that this function operates
             similarly to `NamespaceManager.qname`.
 
-        :param uri: URI to generate CURIE for.
-        :param generate: Whether to add a prefix for the namespace if one doesn't
-            already exist.  Default: `True`.
-        :return: CURIE for the URI.
-        :raises KeyError: If generate is `False` and the namespace doesn't already have
-            a prefix.
+        Args:
+            uri: URI to generate CURIE for.
+            generate: Whether to add a prefix for the namespace if one doesn't
+                already exist.  Default: `True`.
+
+        Returns:
+            CURIE for the URI
+
+        Raises:
+            KeyError: If generate is `False` and the namespace doesn't already have
+                a prefix.
         """
         prefix, namespace, name = self.compute_qname(uri, generate=generate)
         return ":".join((prefix, name))
@@ -579,8 +602,8 @@ class NamespaceManager:
             qNameParts = self.compute_qname(rdfTerm)  # noqa: N806
             return ":".join([qNameParts[0], qNameParts[-1]])
 
-    def compute_qname(self, uri: str, generate: bool = True) -> tuple[str, URIRef, str]:
-        prefix: str | None
+    def compute_qname(self, uri: str, generate: bool = True) -> Tuple[str, URIRef, str]:
+        prefix: Optional[str]
         if uri not in self.__cache:
             if not _is_valid_uri(uri):
                 raise ValueError(
@@ -626,12 +649,12 @@ class NamespaceManager:
 
     def compute_qname_strict(
         self, uri: str, generate: bool = True
-    ) -> tuple[str, str, str]:
+    ) -> Tuple[str, str, str]:
         # code repeated to avoid branching on strict every time
         # if output needs to be strict (e.g. for xml) then
         # only the strict output should bear the overhead
         namespace: str
-        prefix: str | None
+        prefix: Optional[str]
         prefix, namespace, name = self.compute_qname(uri, generate)
         if is_ncname(str(name)):
             return prefix, namespace, name
@@ -719,7 +742,7 @@ class NamespaceManager:
             return self.store.bind(prefix, namespace, override=override)
         except TypeError as error:
             if "override" in str(error):
-                logger.warning(
+                logger.debug(
                     "caught a TypeError, "
                     "retrying call to %s.bind without override, "
                     "see https://github.com/RDFLib/rdflib/issues/1880 for more info",
@@ -730,7 +753,7 @@ class NamespaceManager:
 
     def bind(
         self,
-        prefix: str | None,
+        prefix: Optional[str],
         namespace: Any,
         override: bool = True,
         replace: bool = False,
@@ -741,7 +764,6 @@ class NamespaceManager:
         bound to another prefix.
 
         If replace, replace any existing prefix with the new namespace
-
         """
 
         namespace = URIRef(str(namespace))
@@ -795,7 +817,7 @@ class NamespaceManager:
 
         insert_trie(self.__trie, str(namespace))
 
-    def namespaces(self) -> Iterable[tuple[str, URIRef]]:
+    def namespaces(self) -> Iterable[Tuple[str, URIRef]]:
         for prefix, namespace in self.store.namespaces():
             namespace = URIRef(namespace)
             yield prefix, namespace
@@ -878,8 +900,8 @@ def is_ncname(name: str) -> int:
 
 
 def split_uri(
-    uri: str, split_start: list[str] = SPLIT_START_CATEGORIES
-) -> tuple[str, str]:
+    uri: str, split_start: List[str] = SPLIT_START_CATEGORIES
+) -> Tuple[str, str]:
     if uri.startswith(XMLNS):
         return (XMLNS, uri.split(XMLNS)[1])
     length = len(uri)
@@ -901,8 +923,8 @@ def split_uri(
 
 
 def insert_trie(
-    trie: dict[str, Any], value: str
-) -> dict[str, Any]:  # aka get_subtrie_or_insert
+    trie: Dict[str, Any], value: str
+) -> Dict[str, Any]:  # aka get_subtrie_or_insert
     """Insert a value into the trie if it is not already contained in the trie.
     Return the subtree for the value regardless of whether it is a new value
     or not."""
@@ -925,12 +947,12 @@ def insert_trie(
     return trie[value]
 
 
-def insert_strie(strie: dict[str, Any], trie: dict[str, Any], value: str) -> None:
+def insert_strie(strie: Dict[str, Any], trie: Dict[str, Any], value: str) -> None:
     if value not in strie:
         strie[value] = insert_trie(trie, value)
 
 
-def get_longest_namespace(trie: dict[str, Any], value: str) -> str | None:
+def get_longest_namespace(trie: Dict[str, Any], value: str) -> Optional[str]:
     for key in trie:
         if value.startswith(key):
             out = get_longest_namespace(trie[key], value)
